% saveBoxdata2File(x,h,fileName)
% saves boxplot data in a format that can be used in TikZ/pgfplots
% x: the x values
% h: the boxplot handle
% filename: the output filename

function saveBoxdata2File(xV,h,fileName)

    h1 = findobj(h,'tag','Median');
    xdata = get(h1,'XData');
    ydata = get(h1,'YData');

    N = length(xdata);
    X = zeros(N,6);
    
    % extract median
    for n = 1:N
        X(n,1) = xV(mean(xdata{n}));
        X(n,2) = mean(ydata{n});
    end

    % extract lower whisker
    h1 = findobj(h,'tag','Lower Whisker');
    ydata = get(h1,'YData');
    X(:,[6,4]) = cell2mat(ydata);
    
    % extract upper whisker
    h1 = findobj(h,'tag','Upper Whisker');
    ydata = get(h1,'YData');
    X(:,[3,5]) = cell2mat(ydata);
        
    % extract outliers
    h1 = findobj(h,'tag','Outliers');
    outliersY = get(h1,'YData');
    outliersX = get(h1,'XData');
    Y = [];
    for n = 1:N
        if ~isnan(outliersX{n})
            Y = [Y;xV(outliersX{n})' outliersY{n}'];
        end
    end
    
    % the box
    cNames = {'index','median','lower wisker','lower percentile',...
        'upper percentile','upper whisker'};
    saveMatrix2File(fileName,X,4,cNames);

    % the outliers
    oFile = strcat(fileName(1:end-4),'_outliers.csv');
    saveMatrix2File(oFile,Y,4,{'index','value'});

end
